import Foundation

// EXPLANATION:
// 1. For JSON payloads that are unnamed arrays, decide on a name for each item in the array. For example, Rocket or RocketModel
// 2. Create a typealias that is the plural of the name. For example, typealias Rockets = [RocketModel]
// 3. Then list out all the dictionary entries in one array item that you're interested in and list them as variables / constants
// 4. For entries with nested entries / containers, make a separate struct, following the pattern used above (excluding the typealias) and assign the struct as the type of one of the items in the parent container. For example, 'Height' below.
// 5. Rinse and repeat until you have stubs for all the data you're interested in
// 6. Assign the payload to a data object and then decode the dataObject like this:
// let response = try decoder.decode(Rockets.self, from: data)
// 7. Or use QuickType.io :)

public typealias Rockets = [RocketModel]

public struct Height: Codable {
    public let meters: Int
    public let feet: Double
}

public struct RocketModel: Codable {
    
    // IMPORTANT: The variable names here must match those in the CodingKeys enum
    public let id: String
    public let name: String
    public let type: String
    public let active: Bool
    public let stages: Int
    public let boosters: Int
    public let costPerLaunch: Int
    public let successRate: Int
    public let firstFlight: String
    public let country: String
    public let company: String
    public let height: Height
    public let description: String
    
    enum CodingKeys: String, CodingKey {
        case id
        case name
        case type
        case active
        case stages
        case boosters
        case costPerLaunch = "cost_per_launch"
        case successRate = "success_rate_pct"
        case firstFlight = "first_flight"
        case country
        case company
        case height
        case description
    }
    
}

